"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const util_1 = require("./util");
const useBattery = () => {
    const [state, setState] = react_1.useState({});
    let mounted = true;
    let battery = null;
    const onChange = () => {
        const { charging, level, chargingTime, dischargingTime } = battery;
        setState({
            charging,
            level,
            chargingTime,
            dischargingTime
        });
    };
    const onBattery = () => {
        onChange();
        util_1.on(battery, 'chargingchange', onChange);
        util_1.on(battery, 'levelchange', onChange);
        util_1.on(battery, 'chargingtimechange', onChange);
        util_1.on(battery, 'dischargingtimechange', onChange);
    };
    react_1.useEffect(() => {
        navigator.getBattery().then((bat) => {
            if (mounted) {
                battery = bat;
                onBattery();
            }
        });
        return () => {
            mounted = false;
            if (battery) {
                util_1.off(battery, 'chargingchange', onChange);
                util_1.off(battery, 'levelchange', onChange);
                util_1.off(battery, 'chargingtimechange', onChange);
                util_1.off(battery, 'dischargingtimechange', onChange);
            }
        };
    }, [0]);
    return state;
};
exports.default = useBattery;
