"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const { useState, useEffect } = React;
const defaults = {
    useKeyboardJS: false
};
const useKeyPress = (targetKey, config = defaults) => {
    const [state, setState] = useState(false);
    const { useKeyboardJS } = config;
    let keyboardjs;
    if (useKeyboardJS) {
        Promise.resolve().then(() => require("keyboardjs")).then(module => {
            keyboardjs = module;
        });
    }
    const regularDownHandler = ({ key }) => {
        if (key === targetKey) {
            setState(true);
        }
    };
    const regularUpHandler = ({ key }) => {
        if (key === targetKey) {
            setState(false);
        }
    };
    const customDownHandler = () => {
        setState(true);
    };
    const customUpHandler = () => {
        setState(false);
    };
    useEffect(() => {
        if (useKeyboardJS) {
            keyboardjs.bind(targetKey, customDownHandler, customUpHandler);
        }
        else {
            window.addEventListener("keydown", regularDownHandler);
            window.addEventListener("keyup", regularUpHandler);
        }
        return () => {
            if (useKeyboardJS) {
                keyboardjs.unbind(targetKey, customDownHandler, customUpHandler);
            }
            else {
                window.removeEventListener("keydown", regularDownHandler);
                window.removeEventListener("keyup", regularUpHandler);
            }
        };
    }, [targetKey, useKeyPress]);
    return state;
};
exports.default = useKeyPress;
